import React from 'react';
import { Terminal } from 'lucide-react';
import TerminalButton from './components/TerminalButton';
import ProfileContent from './components/ProfileContent';
import ProjectsContent from './components/ProjectsContent';
import TerminalShell from './components/TerminalShell';
import SkillsContent from './components/SkillsContent';
import ResumeContent from './components/ResumeContent';
import PostsContent from './components/PostsContent';

function App() {
  const [activeSection, setActiveSection] = React.useState('about');
  const [isBooting, setIsBooting] = React.useState(true);
  const [bootPhase, setBootPhase] = React.useState(0);

  // TV Boot-up sequence
  React.useEffect(() => {
    if (!isBooting) return;

    // Phase 0: Initial black screen (0ms)
    // Phase 1: Quick white flash (100ms)
    // Phase 2: Static noise (600ms)
    // Phase 3: Horizontal scan line (900ms) 
    // Phase 4: Fade in content (1200ms)
    // Phase 5: Boot complete (1800ms)
    
    const timings = [0, 100, 600, 900, 1200, 1800];
    
    const bootSequence = timings.map((time, index) => {
      return setTimeout(() => {
        setBootPhase(index);
        if (index === timings.length - 1) {
          setIsBooting(false);
        }
      }, time);
    });
    
    return () => {
      bootSequence.forEach(timeout => clearTimeout(timeout));
    };
  }, [isBooting]);

  return (
    <div className="min-h-screen bg-gray-900 flex items-center justify-center overflow-hidden">
      {/* TV Container with fixed proportions */}
      <div className="w-[95%] max-w-[1400px] relative h-[90vh]">
        {/* TV Frame */}
        <div className="absolute inset-0 tv-frame">
          {/* TV frame texture overlay */}
          <div className="tv-frame-texture"></div>
          
          {/* Edge shadow for added depth */}
          <div className="tv-frame-edge"></div>
          
          {/* Screen Container with fixed height and Convex Effect */}
          <div className="relative w-full h-full rounded-[20px] overflow-hidden tv-screen-container">
            {/* Convex Screen Effect */}
            <div className="absolute inset-0 tv-screen-convex"></div>
            
            {/* Boot-up Animation Layers */}
            {isBooting && (
              <>
                {/* Black Screen (initial) */}
                <div className={`absolute inset-0 bg-black z-30 transition-opacity duration-500 ${bootPhase >= 1 ? 'opacity-0' : 'opacity-100'}`}></div>
                
                {/* Power On Flash */}
                <div className={`absolute inset-0 bg-white z-30 transition-opacity duration-300 ${bootPhase === 1 ? 'opacity-80' : 'opacity-0'}`}></div>
                
                {/* Intense Static */}
                <div className={`absolute inset-0 z-30 transition-opacity duration-300 ${bootPhase === 2 ? 'opacity-100' : 'opacity-0'}`}>
                  <div className="absolute inset-0 bg-black opacity-30"></div>
                  <div className="absolute inset-0" style={{
                    backgroundImage: `url("data:image/svg+xml,%3Csvg viewBox='0 0 250 250' xmlns='http://www.w3.org/2000/svg'%3E%3Cfilter id='noiseFilter'%3E%3CfeTurbulence type='fractalNoise' baseFrequency='0.65' numOctaves='3' stitchTiles='stitch'/%3E%3C/filter%3E%3Crect width='100%25' height='100%25' filter='url(%23noiseFilter)'/%3E%3C/svg%3E")`,
                    opacity: 1
                  }}></div>
                </div>
                
                {/* Horizontal Scan Line */}
                {bootPhase === 3 && (
                  <div className="absolute inset-0 z-30">
                    <div className="h-8 w-full bg-white opacity-60 animate-scanline"></div>
                  </div>
                )}
                
                {/* Content Fade Overlay */}
                <div className={`absolute inset-0 bg-black z-20 pointer-events-none transition-opacity duration-500 ${bootPhase >= 4 ? 'opacity-0' : 'opacity-100'}`}></div>
              </>
            )}
            
            {/* Static noise texture underlay */}
            <div className="white-noise"></div>

            {/* Screen Content with fixed height */}
            <div className="relative h-full w-full p-6 font-mono text-[#00FF00] overflow-hidden z-10 screen-content">
              <div className="animate-pulse mb-4">
                <Terminal className="inline-block mr-2" />
                <span className="text-sm">echo "Hey there!"</span>
              </div>

              {/* Split Screen Container with fixed height */}
              <div className="flex gap-8 h-[calc(100%-3rem)]">
                {/* Left Column - Navigation */}
                <div className="w-64 space-y-3 overflow-y-auto custom-scrollbar">
                  <TerminalButton
                    onClick={() => setActiveSection('about')}
                    isSelected={activeSection === 'about'}
                  >
                    ABOUT
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('projects')}
                    isSelected={activeSection === 'projects'}
                  >
                    PROJECTS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('skills')}
                    isSelected={activeSection === 'skills'}
                  >
                    SKILLS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('posts')}
                    isSelected={activeSection === 'posts'}
                  >
                    POSTS
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('resume')}
                    isSelected={activeSection === 'resume'}
                  >
                    RESUME
                  </TerminalButton>
                  <TerminalButton
                    onClick={() => setActiveSection('shell')}
                    isSelected={activeSection === 'shell'}
                  >
                    SHELL
                  </TerminalButton>
                </div>

                {/* Vertical Separator with embossed effect */}
                <div className="vertical-separator"></div>

                {/* Right Column - Content with scrolling */}
                <div className="flex-1 overflow-y-auto pr-4 custom-scrollbar">
                  {activeSection === 'about' && <ProfileContent />}
                  {activeSection === 'projects' && (
                    <ProjectsContent markdownPath="/content/projects.md" />
                  )}
                  {activeSection === 'skills' && <SkillsContent />}
                  {activeSection === 'posts' && <PostsContent />}
                  {activeSection === 'resume' && <ResumeContent />}
                  {activeSection === 'shell' && <TerminalShell />}
                </div>
              </div>
            </div>

            {/* Enhanced Scan Lines Effect */}
            <div className="scan-lines"></div>

            {/* Chromatic Aberration Effect */}
            <div className="chromatic-aberration"></div>

            {/* Multiple Glass Reflection Layers */}
            <div className="glass-reflection"></div>
            <div className="glass-reflection-2"></div>
            <div className="corner-shine"></div>

            {/* Screen Glare - Moving reflection */}
            <div className="screen-glare"></div>
          </div>
        </div>

        {/* TV Controls - Skeuomorphic Knobs */}
        <div className="absolute -bottom-12 right-20 flex space-x-8">
          <div className="tv-knob" style={{transform: 'rotate(-30deg)'}}></div>
          <div className="tv-knob" style={{transform: 'rotate(15deg)'}}></div>
          <div className="tv-knob" style={{transform: 'rotate(-10deg)'}}></div>
        </div>

        {/* TV Speaker Grills - Enhanced */}
        <div className="absolute -bottom-6 left-20 flex space-x-1.5">
          {[...Array(10)].map((_, i) => (
            <div 
              key={i} 
              className="w-1.5 h-6 bg-gradient-to-b from-gray-600 to-gray-800 rounded-full"
              style={{
                boxShadow: 'inset 0 1px 1px rgba(255,255,255,0.1), inset 0 -1px 1px rgba(0,0,0,0.3)'
              }}
            ></div>
          ))}
        </div>

        {/* TV Brand Label */}
        <div 
          className="absolute -bottom-10 left-1/2 transform -translate-x-1/2 bg-gradient-to-b from-gray-700 to-gray-900 px-4 py-1 rounded"
          style={{
            boxShadow: 'inset 0 1px 1px rgba(255,255,255,0.2), 0 1px 2px rgba(0,0,0,0.5)',
            border: '1px solid rgba(0,0,0,0.3)'
          }}
        >
          <span 
            className="text-xs text-gray-300 font-bold"
            style={{
              textShadow: '0 -1px 0 rgba(0,0,0,0.5)'
            }}
          >
            RETRO·VISION
          </span>
        </div>

        {/* Power indicator light */}
        <div className="absolute -bottom-8 right-[12%] w-3 h-3 rounded-full bg-gradient-to-b from-green-500 to-green-700" 
          style={{
            boxShadow: '0 0 5px #4AFF4A, inset 0 1px 2px rgba(255,255,255,0.4), inset 0 -1px 2px rgba(0,0,0,0.4)'
          }}>
          <div className="absolute inset-0 rounded-full bg-green-400 opacity-50 animate-pulse"></div>
        </div>
      </div>
    </div>
  );
}

export default App;